@@ -26,7 +26,7 @@
 #include "check_utils.h"
 #include "epn_utils.h"
 #include "worker_client.h"
-#include "gearman.h"
+#include "gearman_utils.h"
 
 #ifdef EMBEDDEDPERL
 #include <EXTERN.h>
