@@ -48,12 +48,13 @@
 #include <config.h>
 #include <stdio.h>
 #include <sys/time.h>
+#include <arpa/inet.h>
 
 #ifndef MOD_GM_COMMON_H
 #define MOD_GM_COMMON_H
 
 /* constants */
-#define GM_VERSION                 "1.2.2"
+#define GM_VERSION                 "1.2.8"
 #define GM_ENABLED                      1
 #define GM_DISABLED                     0
 #define GM_BUFFERSIZE               98304
@@ -101,13 +102,14 @@
 /* worker */
 #define GM_DEFAULT_MIN_WORKER           1      /**< minumum number of worker             */
 #define GM_DEFAULT_MAX_WORKER          20      /**< maximum number of concurrent worker  */
-#define GM_DEFAULT_JOB_MAX_AGE        600      /**< discard jobs older than that         */
+#define GM_DEFAULT_JOB_MAX_AGE          0      /**< discard jobs older than that         */
 #define GM_DEFAULT_SPAWN_RATE           1      /**< number of spawned worker per seconds */
 #define GM_DEFAULT_WORKER_LOOP_SLEEP    1      /**< sleep in worker main loop */
 
 /* transport modes */
 #define GM_ENCODE_AND_ENCRYPT           1
 #define GM_ENCODE_ONLY                  2
+#define GM_ENCODE_ACCEPT_ALL            3
 
 /* dump config modes */
 #define GM_WORKER_MODE                  1
@@ -152,6 +154,16 @@ typedef struct mod_gm_export {
     int      elem_number;                   /**< number of elements */
 } mod_gm_exp_t;
 
+/** server structure
+ *
+ * structure for server definition
+ *
+ */
+typedef struct gm_server {
+    char            * host;                 /**< hostname of server */
+    in_port_t       port;                   /**< port number */
+} gm_server_t;
+
 /** options structure
  *
  * structure union for all components
@@ -163,9 +175,9 @@ typedef struct mod_gm_opt_struct {
 
     char         * crypt_key;                               /**< encryption key used for securing the messages sent over gearman */
     char         * keyfile;                                 /**< path to a file where the crypt_key is read from */
-    char         * server_list[GM_LISTSIZE];                /**< list of gearmand servers */
+    gm_server_t  * server_list[GM_LISTSIZE];                /**< list of gearmand servers */
     int            server_num;                              /**< number of gearmand servers */
-    char         * dupserver_list[GM_LISTSIZE];             /**< list of gearmand servers to duplicate results */
+    gm_server_t  * dupserver_list[GM_LISTSIZE];             /**< list of gearmand servers to duplicate results */
     int            dupserver_num;                           /**< number of duplicate gearmand servers */
     char         * hostgroups_list[GM_LISTSIZE];            /**< list of hostgroups which get own queues */
     int            hostgroups_num;                          /**< number of elements in hostgroups_list */
@@ -191,10 +203,12 @@ typedef struct mod_gm_opt_struct {
     char         * local_servicegroups_list[GM_LISTSIZE];   /**< list of group  which will not be distributed */
     int            local_servicegroups_num;                 /**< number of elements in local_servicegroups_list */
     int            do_hostchecks;                           /**< flag whether mod-gearman will process hostchecks at all */
+    char         * queue_cust_var;                          /**< custom variable name which contains the target queue */
     mod_gm_exp_t * exports[GM_NEBTYPESSIZE];                /**< list of exporter queues */
     int            exports_count;                           /**< number of export queues */
     int            orphan_host_checks;                      /**< generate fake result for orphaned host checks */
     int            orphan_service_checks;                   /**< generate fake result for orphaned service checks */
+    int            accept_clear_results;                    /**< accept unencrypted results */
 /* worker */
     char         * identifier;                              /**< identifier for this worker */
     char         * pidfile;                                 /**< path to a pidfile */
@@ -208,6 +222,7 @@ typedef struct mod_gm_opt_struct {
     int            max_jobs;                                /**< maximum number of jobs done after a worker exits */
     int            spawn_rate;                              /**< number of spawned new worker */
     int            show_error_output;                       /**< optional display the stderr output of plugins */
+    int            dup_results_are_passive;                 /**< send duplicate results as passive checks */
 #ifdef EMBEDDEDPERL
     int            enable_embedded_perl;                    /**< enabled embedded perl */
     int            use_embedded_perl_implicitly;            /**< use embedded perl implicitly */
@@ -245,7 +260,8 @@ typedef struct gm_job_struct {
     int            exited_ok;           /**< did the plugin exit normally? */
     int            timeout;             /**< timeout for this job */
     double         latency;             /**< latency for from this job */
-    struct timeval core_start_time;     /**< time when the core started the job */
+    struct timeval next_check;          /**< next_check value of host / service */
+    struct timeval core_time;           /**< time when the core started the job */
     struct timeval start_time;          /**< time when the job really started */
     struct timeval finish_time;         /**< time when the job was finished */
 } gm_job_t;
